@@ -1,9 +1,16 @@
 import time
 
-from flex_optimization.problem_statement import StopCriteria
+from flex_optimization.core.stop_criteria import StopCriteria
 
 
 class StopComputationTime(StopCriteria):
+    """
+    Stop Criteria: Computation Time
+
+    Stop the algorithm after 'duration' (time that has passed).
+    * It will finish current iteration before stopping.
+
+    """
     def __init__(self, duration: float = 120):
         self.duration = duration  # seconds
         self.start_time = time.monotonic()  # seconds
